pub struct RawFile { /* private fields */ }Expand description
Use for file size less than 2G If the file size is greater than 2G, there is a risk of precision loss, it is recommended to use RawFile64
Implementations