RawFile64

Struct RawFile64 

pub struct RawFile64 { /* private fields */ }

Implementations

Source

impl RawFile64

Using for file size. Recommended to use this type if the file size is greater than 2G

pub fn from_raw(raw: *mut RawFile64) -> Self

pub fn file_size(&self) -> i64

pub fn seek(&self, offset: i64, whence: i32) -> i32

pub fn offset(&self) -> i64

pub fn read(&self, len: i64) -> Vec<u8>

pub fn remain(&self) -> i64

pub fn fd(&self, start: i64, len: i64) -> i32

try to get fd with start and length get failed it will return -1 and then return fd