pub struct RawFile64 { /* private fields */ }Implementations
Sourceimpl RawFile64
Using for file size.
Recommended to use this type if the file size is greater than 2G
impl RawFile64
Using for file size. Recommended to use this type if the file size is greater than 2G